@@ -1,8 +1,11 @@
 #' Get the average nLTT from a collection of phylogenies
 #'
-#' @param phylogenies the phylogenies, supplied as either a list or a multiPhylo object, where the phylogenies are of type 'phylo'
-#' @param dt The timestep resolution, where 1/dt is the number of points evaluated
-#' @return A matrix of timepoints with the average number of (normalized) lineages through (normalized) time
+#' @param phylogenies the phylogenies, supplied as either a list
+#'   or a multiPhylo object, where the phylogenies are of type 'phylo'
+#' @param dt The timestep resolution, where 1/dt is
+#'   the number of points evaluated
+#' @return A matrix of timepoints with the average number of (normalized)
+#'   lineages through (normalized) time
 #' @examples
 #'   get_average_nltt_matrix(c(ape::rcoal(10), ape::rcoal(20)))
 #'
@@ -29,6 +32,7 @@ get_average_nltt_matrix <- function(
 
   nltts <- NULL
   for (phylogeny in phylogenies) {
+    testit::assert(length(phylogeny$tip.label) > 0)
     nltts <- c(nltts, list(nLTT::get_phylogeny_nltt_matrix(phylogeny)))
   }
   testit::assert(length(nltts) == length(phylogenies))
@@ -36,15 +40,17 @@ get_average_nltt_matrix <- function(
   stretch_matrices <- NULL
   for (nltt in nltts) {
     stretch_matrix <- nLTT::stretch_nltt_matrix(
-      nltt, dt = dt, step_type = "upper"
+      m = nltt, dt = dt, step_type = "upper"
     )
     stretch_matrices <- c(stretch_matrices, list(stretch_matrix))
   }
   testit::assert(length(stretch_matrices) == length(nltts))
 
   xy <- stretch_matrices[[1]]
-  for (i in seq(2, sz)) {
-    xy <- (xy + stretch_matrices[[i]])
+  if (sz > 1) {
+    for (i in seq(2, sz)) {
+      xy <- (xy + stretch_matrices[[i]])
+    }
   }
   xy <- (xy / sz)
 
