@@ -12,9 +12,16 @@
 #
 #
 ################################################################################
-#' This function uses a modified version of the ltt.plot function from \code{"ape"} to plot the normalized number of lineages through normalized time, where the number of lineages is normalized by dividing by the number of tips of the tree, and the time is normalized by the total time between the most common recent ancestor and the present, such that t(MRCA) = 0 & t(present) = 1.
+#' This function uses a modified version of the ltt.plot function
+#'   from \code{"ape"} to plot the normalized number of lineages
+#'   through normalized time, where the number of lineages is normalized
+#'   by dividing by the number of tips of the tree,
+#'   and the time is normalized by the total time between
+#'   the most common recent ancestor and the present,
+#'   such that t(MRCA) = 0 & t(present) = 1.
 #' @title Normalized version of the ape function ltt.plot
-#' @usage nltt_plot(phy, xlab = "Normalized Time", ylab = "Normalized Lineages", ...)
+#' @usage nltt_plot(
+#'   phy, xlab = "Normalized Time", ylab = "Normalized Lineages", ...)
 #' @param phy an object of class \code{"phylo"}
 #' @param xlab a character string (or a variable of mode character)
 #'   giving the label for the \eqn{x}-axis (default is "Normalized Time").
@@ -31,13 +38,14 @@ nltt_plot <- function( phy, xlab = "Normalized Time",
 
   if (!inherits(phy, "phylo")) {
     # Stop imposed by ape::ltt.plot.coords
-    stop("nltt_plot: ",
+    stop(
       "phylogeny must be of class 'phylo', ",
-      "but was of type '", class(phy), "' instead")
+      "but was of type '", class(phy), "' instead"
+    )
   }
 
   #we use the ltt.plot.coords function from the package ape
-  xy <- ape::ltt.plot.coords( phy, backward = TRUE, tol = 1e-6)
+  xy <- ape::ltt.plot.coords(phy, backward = TRUE, tol = 1e-6)
   xy[, 2] <- xy[, 2] / max(xy[, 2]) #normalize number lineages
 
   xy[, 1] <- xy[, 1] + abs( min( xy[, 1])) #make sure time runs from 0..T
@@ -58,7 +66,9 @@ nltt_plot <- function( phy, xlab = "Normalized Time",
 #
 #
 ################################################################################
-#' This is a modified version of the \code{ape} function ltt.lines: add the normalized Lineage-Through-Time statistic of a phylogenetic tree to an already existing plot
+#' This is a modified version of the \code{ape} function ltt.lines:
+#'   add the normalized Lineage-Through-Time statistic of a phylogenetic tree
+#'   to an already existing plot
 #' @title Normalized version of the ape function ltt.lines.
 #' @usage nltt_lines(phy, ...)
 #' @param phy an object of class \code{"phylo"}
@@ -73,14 +83,15 @@ nltt_lines <- function(phy, ...) {
 
   if (!inherits(phy, "phylo")) {
     # Stop imposed by ape::ltt.plot.coords
-    stop("nltt_lines: ",
+    stop(
       "phylogeny must be of class 'phylo', ",
-      "but was of type '", class(phy), "' instead")
+      "but was of type '", class(phy), "' instead"
+    )
   }
-  xy <- ape::ltt.plot.coords( phy, backward = TRUE, tol = 1e-6)
-  xy[, 2] <- xy[, 2] / max( xy[, 2]) #normalize number lineages
+  xy <- ape::ltt.plot.coords(phy, backward = TRUE, tol = 1e-6)
+  xy[, 2] <- xy[, 2] / max(xy[, 2]) #normalize number lineages
 
-  xy[, 1] <- xy[, 1] + abs( min( xy[, 1])) #make sure time runs from 0..T
-  xy[, 1] <- xy[, 1] / max( xy[, 1])      #normalize time
+  xy[, 1] <- xy[, 1] + abs(min( xy[, 1])) #make sure time runs from 0..T
+  xy[, 1] <- xy[, 1] / max(xy[, 1])      #normalize time
   graphics::lines(xy, type = "S", ...)
 }
